@@ -17,9 +17,9 @@ def test_compile_parser():
     assert isinstance(p, PackratParser)
     assert p.match('a')
 
-    # p = pe.compile(r'"a"', parser='machine')
-    # assert isinstance(p, MachineParser)
-    # assert p.match('a')
+    p = pe.compile(r'"a"', parser='machine')
+    assert isinstance(p, MachineParser)
+    assert p.match('a')
 
 
 def test_compile_actions():
@@ -46,7 +46,6 @@ def test_escape():
     assert pe.escape('\r') == '\\r'
     assert pe.escape('"') == '\\"'
     assert pe.escape("'") == "\\'"
-    assert pe.escape('-') == '\\-'
     assert pe.escape('[') == '\\['
     assert pe.escape('\\') == '\\\\'
     assert pe.escape(']') == '\\]'
@@ -60,7 +59,6 @@ def test_unescape():
     assert pe.unescape('\\r') == '\r'
     assert pe.unescape('\\"') == '"'
     assert pe.unescape("\\'") == "'"
-    assert pe.unescape('\\-') == '-'
     assert pe.unescape('\\[') == '['
     assert pe.unescape('\\\\') == '\\'
     assert pe.unescape('\\]') == ']'
